==> hinemos_src-3.2.1.tar.gz: HinemosManager/src_jobmanagement/com/clustercontrol/jobmanagement/ejb/entity/JobFileInfoBean.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.ejb.entity;

import java.util.Collection;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl;

/**
 * ジョブファイル転送情報のBMP Entity Bean クラス<BR>
 * 
 * @ejb.bean name="JobFileInfo"
 *    jndi-name="JobFileInfo"
 *    type="BMP"
 *    view-type="local" 
 * 
 * @jboss.container-configuration
 *    name="Hinemos Log BMP EntityBean"
 * 
 * @jboss.depends
 *    name="jboss.jca:service=DataSourceBinding,name=HinemosDS"
 * 
 * @ejb.dao 
 *    class="com.clustercontrol.jobmanagement.dao.JobFileInfoDAO"
 *    impl-class="com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl"
 * 
 * @ejb.permission
 *    unchecked="true"
 * 
 * @jboss.method-attributes
 *    pattern="get*"
 *    read-only="true"
 * 
 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO
 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl
 */
public abstract class JobFileInfoBean implements javax.ejb.EntityBean {
	/** セッションID */
	protected String session_id;
	/** 所属ジョブユニットのジョブID */
	protected String jobunit_id;
	/** ジョブID */
	protected String job_id;
	/** スコープ処理方法 */
	protected Integer process_mode;
	/** 転送ファシリティID */
	protected String src_facility_id;
	/** 受信ファシリティID */
	protected String dest_facility_id;
	/** ファイル */
	protected String src_file;
	/** 転送作業ディレクトリ */
	protected String src_work_dir;
	/** 受信ディレクトリ */
	protected String dest_directory;
	/** 受信作業ディレクトリ */
	protected String dest_work_dir;
	/** ファイル圧縮 */
	protected Integer compression_flg; 
	/** ファイルチェック */
	protected Integer check_flg;
	/** 実効ユーザ */
	protected String effective_user;
	
	/**
	 * ジョブファイル転送情報を生成します。<BR>
	 * 
	 * @ejb.create-method 
	 * 
	 * @param session_id セッションID
	 * @param jobunit_id 所属ジョブユニットのジョブID
	 * @param job_id ジョブID
	 * @param process_mode スコープ処理方法
	 * @param src_facility_id 転送ファシリティID
	 * @param dest_facility_id 受信ファシリティID
	 * @param src_file ファイル
	 * @param src_work_dir 転送作業ディレクトリ
	 * @param dest_directory 受信ディレクトリ
	 * @param dest_work_dir 受信作業ディレクトリ
	 * @param compression_flg ファイル圧縮
	 * @param check_flg ファイルチェック
	 * @param effective_user 実効ユーザ
	 * @return プライマリーキー
	 * @throws javax.ejb.CreateException
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public JobFileInfoPK ejbCreate(
			String session_id, 
			String jobunit_id, 
			String job_id, 
			Integer process_mode, 
			String src_facility_id, 
			String dest_facility_id, 
			String src_file, 
			String src_work_dir, 
			String dest_directory, 
			String dest_work_dir, 
			Integer compression_flg, 
			Integer check_flg, 
			String effective_user
	) throws javax.ejb.CreateException {
		this.session_id = session_id;
		this.jobunit_id = jobunit_id;
		this.job_id = job_id;
		this.process_mode = process_mode;
		this.src_facility_id = src_facility_id;
		this.dest_facility_id = dest_facility_id;
		this.src_file = src_file;
		this.src_work_dir = src_work_dir;
		this.dest_directory = dest_directory;
		this.dest_work_dir = dest_work_dir;
		this.compression_flg = compression_flg;
		this.check_flg = check_flg;
		this.effective_user = effective_user;
		return null;
	}
	
	/**
	 * 全てのジョブファイル転送情報を検索します。<BR>
	 * 
	 * @return プライマリキーのコレクション
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#findAll()
	 */
	public Collection ejbFindAll() throws FinderException {
		return null;
	}
	
	/**
	 * プライマリキーに一致するジョブファイル転送情報を検索します。<BR>
	 * 
	 * @param pk プライマリキー
	 * @return プライマリキー
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#findByPrimaryKey(JobFileInfoPK)
	 */
	public JobFileInfoPK ejbFindByPrimaryKey(JobFileInfoPK pk) throws FinderException {
		return null;
	}
	
	/**
	 * ジョブファイル転送情報のデータオブジェクトを取得します。<BR>
	 * 
	 * @ejb.interface-method view-type="local" 
	 * 
	 * @return ジョブファイル転送情報のデータオブジェクト
	 */
	public JobFileInfoData getJobFileInfoData(){ 
		return new JobFileInfoData(
				this.getSession_id(), 
				this.getJobunit_id(), 
				this.getJob_id(), 
				this.getSrc_facility_id(), 
				this.getDest_facility_id(), 
				this.getProcess_mode(), 
				this.getSrc_file(), 
				this.getSrc_work_dir(), 
				this.getDest_directory(), 
				this.getDest_work_dir(), 
				this.getCompression_flg(), 
				this.getCheck_flg(), 
				this.getEffective_user()); 
	}

	/**
	 * セッションIDを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.pk-field 
	 * @ejb.interface-method
	 * 
	 * @return セッションID
	 */
    public java.lang.String getSession_id() {
    	return session_id;
    }

	/**
	 * セッションIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param session_id セッションID
	 */
    public void setSession_id(java.lang.String session_id) {
    	this.session_id = session_id;
    }
	
	/**
	 * 所属ジョブユニットのジョブIDを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.pk-field 
	 * @ejb.interface-method
	 * 
	 * @return 所属ジョブユニットのジョブID
	 */
	public java.lang.String getJobunit_id() {
		return jobunit_id;
	}
	
	/**
	 * 所属ジョブユニットのジョブIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param jobunit_id 所属ジョブユニットのジョブID
	 */
	public void setJobunit_id(java.lang.String jobunit_id) {
		this.jobunit_id = jobunit_id;
	}
	
	/**
	 * ジョブIDを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.pk-field 
	 * @ejb.interface-method
	 * 
	 * @return ジョブID
	 */
	public java.lang.String getJob_id() {
		return job_id;
	}

	/**
	 * ジョブIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param job_id ジョブID
	 */
	public void setJob_id(java.lang.String job_id) {
		this.job_id = job_id;
	}
	
	/**
	 * 転送ファシリティIDを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 転送ファシリティID
	 */
	public java.lang.String getSrc_facility_id() {
		return src_facility_id;
	}
	
	/**
	 * 転送ファシリティIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_facility_id 転送ファシリティID
	 */
	public void setSrc_facility_id(java.lang.String src_facility_id) {
		this.src_facility_id = src_facility_id;
	}
	
	/**
	 * 受信ファシリティIDを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 受信ファシリティID
	 */
	public java.lang.String getDest_facility_id() {
		return dest_facility_id;
	}
	
	/**
	 * 受信ファシリティIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_facility_id 受信ファシリティID
	 */
	public void setDest_facility_id(java.lang.String dest_facility_id) {
		this.dest_facility_id = dest_facility_id;
	}
	
	/**
	 * スコープ処理方法を返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return スコープ処理方法
	 * 
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public java.lang.Integer getProcess_mode() {
		return process_mode;
	}
	
	/**
	 * スコープ処理方法を設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param process_mode スコープ処理方法
	 * 
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public void setProcess_mode(java.lang.Integer process_mode) {
		this.process_mode = process_mode;
	}
	
	/**
	 * ファイルを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return ファイル
	 */
	public java.lang.String getSrc_file() {
		return src_file;
	}
	
	/**
	 * ファイルを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_file ファイル
	 */
	public void setSrc_file(java.lang.String src_file) {
		this.src_file = src_file;
	}
	
	/**
	 * 転送作業ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 転送作業ディレクトリ
	 */
	public java.lang.String getSrc_work_dir() {
		return src_work_dir;
	}
	
	/**
	 * 転送作業ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_work_dir 転送作業ディレクトリ
	 */
	public void setSrc_work_dir(java.lang.String src_work_dir) {
		this.src_work_dir = src_work_dir;
	}
	
	/**
	 * 受信ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 受信ディレクトリ
	 */
	public  java.lang.String getDest_directory() {
		return dest_directory;
	}
	
	/**
	 * 受信ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_directory 受信ディレクトリ
	 */
	public void setDest_directory(java.lang.String dest_directory) {
		this.dest_directory = dest_directory;
	}
	
	/**
	 * 受信作業ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 受信作業ディレクトリ
	 */
	public java.lang.String getDest_work_dir() {
		return dest_work_dir;
	}
	
	/**
	 * 受信作業ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_work_dir 受信作業ディレクトリ
	 */
	public void setDest_work_dir(java.lang.String dest_work_dir) {
		this.dest_work_dir = dest_work_dir;
	}
	
	/**
	 * ファイル圧縮を返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return ファイル圧縮
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public java.lang.Integer getCompression_flg() {
		return compression_flg;
	}
	
	/**
	 * ファイル圧縮を設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param compression_flg ファイル圧縮
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public void setCompression_flg(java.lang.Integer compression_flg) {
		this.compression_flg = compression_flg;
	}
	
	/**
	 * ファイルチェックを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return ファイルチェック
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public java.lang.Integer getCheck_flg() {
		return check_flg;
	}
	
	/**
	 * ファイルチェックを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param check_flg ファイルチェック
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public void setCheck_flg(java.lang.Integer check_flg) {
		this.check_flg = check_flg;
	}
	
	/**
	 * 実効ユーザを返す。<BR>
	 * 
	 * @ejb.persistent-field 
	 * @ejb.interface-method
	 * 
	 * @return 実効ユーザ
	 */
	public java.lang.String getEffective_user() {
		return effective_user;
	}
	
	/**
	 * 実効ユーザを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param effective_user 実効ユーザ
	 */
	public void setEffective_user(java.lang.String effective_user) {
		this.effective_user = effective_user;
	}
	
	/**
	 * ジョブ情報を取得する。<BR>
	 * 
	 * @ejb.interface-method view-type="local"
	 * 
	 * @return ジョブ情報
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoUtil
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean#ejbFindByPrimaryKey(JobInfoPK)
	 */
    public JobInfoLocal getJobInfo() {
		JobInfoLocal jobInfo = null;
		try {
			jobInfo = JobInfoUtil.getLocalHome().findByPrimaryKey(new JobInfoPK(getSession_id(), getJobunit_id(), getJob_id()));
		} catch (FinderException e) {
		} catch (NamingException e) {
		}
		return jobInfo;
	}
    
	/**
	 * 履歴情報を作成する。<BR>
	 * ジョブファイル転送情報をジョブファイル転送マスタから作成します。<BR>
	 * 
	 * @ejb.home-method view-type="both"
	 * 
	 * @param sessionId セッションID
	 * @param jobunitId 所属ジョブユニットのジョブID
	 * @param jobs ジョブIDのコレクション
	 * @throws javax.ejb.CreateException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#makeSession(String, String, Collection)
	 */
    public Collection ejbHomeMakeSession(String sessionId, String jobunitId, Collection jobs) throws javax.ejb.CreateException{
    	JobFileInfoDAOImpl jfiDAO = new JobFileInfoDAOImpl(); 
    	
    	return jfiDAO.makeSession(sessionId, jobunitId, jobs);
    }
    
}

==> hinemos_src-4.0.0.tar.gz: HinemosManager/src_jobmanagement/com/clustercontrol/jobmanagement/ejb/entity/JobFileInfoBean.java <==
/*

Copyright (C) 2006 NTT DATA Corporation

This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.

This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE.  See the GNU General Public License for more details.

 */

package com.clustercontrol.jobmanagement.ejb.entity;

import java.util.Collection;

import javax.ejb.FinderException;
import javax.naming.NamingException;

import com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl;

/**
 * ジョブファイル転送情報のBMP Entity Bean クラス<BR>
 * 
 * @ejb.bean name="JobFileInfo"
 *    jndi-name="JobFileInfo"
 *    type="BMP"
 *    view-type="local"
 * 
 * @jboss.container-configuration
 *    name="Hinemos Log BMP EntityBean"
 * 
 * @jboss.depends
 *    name="jboss.jca:service=DataSourceBinding,name=DefaultDS"
 * 
 * @ejb.dao
 *    class="com.clustercontrol.jobmanagement.dao.JobFileInfoDAO"
 *    impl-class="com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl"
 * 
 * @ejb.permission
 *    unchecked="true"
 * 
 * @jboss.method-attributes
 *    pattern="get*"
 *    read-only="true"
 * 
 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAO
 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl
 */
public abstract class JobFileInfoBean implements javax.ejb.EntityBean {
	/** セッションID */
	protected String session_id;
	/** 所属ジョブユニットのジョブID */
	protected String jobunit_id;
	/** ジョブID */
	protected String job_id;
	/** スコープ処理方法 */
	protected Integer process_mode;
	/** 転送ファシリティID */
	protected String src_facility_id;
	/** 受信ファシリティID */
	protected String dest_facility_id;
	/** ファイル */
	protected String src_file;
	/** 転送作業ディレクトリ */
	protected String src_work_dir;
	/** 受信ディレクトリ */
	protected String dest_directory;
	/** 受信作業ディレクトリ */
	protected String dest_work_dir;
	/** ファイル圧縮 */
	protected Integer compression_flg;
	/** ファイルチェック */
	protected Integer check_flg;
	/** 実効ユーザ */
	protected String effective_user;

	/**
	 * ジョブファイル転送情報を生成します。<BR>
	 * 
	 * @ejb.create-method
	 * 
	 * @param session_id セッションID
	 * @param jobunit_id 所属ジョブユニットのジョブID
	 * @param job_id ジョブID
	 * @param process_mode スコープ処理方法
	 * @param src_facility_id 転送ファシリティID
	 * @param dest_facility_id 受信ファシリティID
	 * @param src_file ファイル
	 * @param src_work_dir 転送作業ディレクトリ
	 * @param dest_directory 受信ディレクトリ
	 * @param dest_work_dir 受信作業ディレクトリ
	 * @param compression_flg ファイル圧縮
	 * @param check_flg ファイルチェック
	 * @param effective_user 実効ユーザ
	 * @return プライマリーキー
	 * @throws javax.ejb.CreateException
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public JobFileInfoPK ejbCreate(
			String session_id,
			String jobunit_id,
			String job_id,
			Integer process_mode,
			String src_facility_id,
			String dest_facility_id,
			String src_file,
			String src_work_dir,
			String dest_directory,
			String dest_work_dir,
			Integer compression_flg,
			Integer check_flg,
			String effective_user
	) throws javax.ejb.CreateException {
		this.session_id = session_id;
		this.jobunit_id = jobunit_id;
		this.job_id = job_id;
		this.process_mode = process_mode;
		this.src_facility_id = src_facility_id;
		this.dest_facility_id = dest_facility_id;
		this.src_file = src_file;
		this.src_work_dir = src_work_dir;
		this.dest_directory = dest_directory;
		this.dest_work_dir = dest_work_dir;
		this.compression_flg = compression_flg;
		this.check_flg = check_flg;
		this.effective_user = effective_user;
		return null;
	}

	/**
	 * 全てのジョブファイル転送情報を検索します。<BR>
	 * 
	 * @return プライマリキーのコレクション
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#findAll()
	 */
	public Collection ejbFindAll() throws FinderException {
		return null;
	}

	/**
	 * プライマリキーに一致するジョブファイル転送情報を検索します。<BR>
	 * 
	 * @param pk プライマリキー
	 * @return プライマリキー
	 * @throws FinderException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#findByPrimaryKey(JobFileInfoPK)
	 */
	public JobFileInfoPK ejbFindByPrimaryKey(JobFileInfoPK pk) throws FinderException {
		return null;
	}

	/**
	 * ジョブファイル転送情報のデータオブジェクトを取得します。<BR>
	 * 
	 * @ejb.interface-method view-type="local"
	 * 
	 * @return ジョブファイル転送情報のデータオブジェクト
	 */
	public JobFileInfoData getJobFileInfoData(){
		return new JobFileInfoData(
				this.getSession_id(),
				this.getJobunit_id(),
				this.getJob_id(),
				this.getSrc_facility_id(),
				this.getDest_facility_id(),
				this.getProcess_mode(),
				this.getSrc_file(),
				this.getSrc_work_dir(),
				this.getDest_directory(),
				this.getDest_work_dir(),
				this.getCompression_flg(),
				this.getCheck_flg(),
				this.getEffective_user());
	}

	/**
	 * セッションIDを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.pk-field
	 * @ejb.interface-method
	 * 
	 * @return セッションID
	 */
	public java.lang.String getSession_id() {
		return session_id;
	}

	/**
	 * セッションIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param session_id セッションID
	 */
	public void setSession_id(java.lang.String session_id) {
		this.session_id = session_id;
	}

	/**
	 * 所属ジョブユニットのジョブIDを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.pk-field
	 * @ejb.interface-method
	 * 
	 * @return 所属ジョブユニットのジョブID
	 */
	public java.lang.String getJobunit_id() {
		return jobunit_id;
	}

	/**
	 * 所属ジョブユニットのジョブIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param jobunit_id 所属ジョブユニットのジョブID
	 */
	public void setJobunit_id(java.lang.String jobunit_id) {
		this.jobunit_id = jobunit_id;
	}

	/**
	 * ジョブIDを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.pk-field
	 * @ejb.interface-method
	 * 
	 * @return ジョブID
	 */
	public java.lang.String getJob_id() {
		return job_id;
	}

	/**
	 * ジョブIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param job_id ジョブID
	 */
	public void setJob_id(java.lang.String job_id) {
		this.job_id = job_id;
	}

	/**
	 * 転送ファシリティIDを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 転送ファシリティID
	 */
	public java.lang.String getSrc_facility_id() {
		return src_facility_id;
	}

	/**
	 * 転送ファシリティIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_facility_id 転送ファシリティID
	 */
	public void setSrc_facility_id(java.lang.String src_facility_id) {
		this.src_facility_id = src_facility_id;
	}

	/**
	 * 受信ファシリティIDを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 受信ファシリティID
	 */
	public java.lang.String getDest_facility_id() {
		return dest_facility_id;
	}

	/**
	 * 受信ファシリティIDを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_facility_id 受信ファシリティID
	 */
	public void setDest_facility_id(java.lang.String dest_facility_id) {
		this.dest_facility_id = dest_facility_id;
	}

	/**
	 * スコープ処理方法を返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return スコープ処理方法
	 * 
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public java.lang.Integer getProcess_mode() {
		return process_mode;
	}

	/**
	 * スコープ処理方法を設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param process_mode スコープ処理方法
	 * 
	 * @see com.clustercontrol.bean.ProcessingMethodConstant
	 */
	public void setProcess_mode(java.lang.Integer process_mode) {
		this.process_mode = process_mode;
	}

	/**
	 * ファイルを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return ファイル
	 */
	public java.lang.String getSrc_file() {
		return src_file;
	}

	/**
	 * ファイルを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_file ファイル
	 */
	public void setSrc_file(java.lang.String src_file) {
		this.src_file = src_file;
	}

	/**
	 * 転送作業ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 転送作業ディレクトリ
	 */
	public java.lang.String getSrc_work_dir() {
		return src_work_dir;
	}

	/**
	 * 転送作業ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param src_work_dir 転送作業ディレクトリ
	 */
	public void setSrc_work_dir(java.lang.String src_work_dir) {
		this.src_work_dir = src_work_dir;
	}

	/**
	 * 受信ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 受信ディレクトリ
	 */
	public  java.lang.String getDest_directory() {
		return dest_directory;
	}

	/**
	 * 受信ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_directory 受信ディレクトリ
	 */
	public void setDest_directory(java.lang.String dest_directory) {
		this.dest_directory = dest_directory;
	}

	/**
	 * 受信作業ディレクトリを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 受信作業ディレクトリ
	 */
	public java.lang.String getDest_work_dir() {
		return dest_work_dir;
	}

	/**
	 * 受信作業ディレクトリを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param dest_work_dir 受信作業ディレクトリ
	 */
	public void setDest_work_dir(java.lang.String dest_work_dir) {
		this.dest_work_dir = dest_work_dir;
	}

	/**
	 * ファイル圧縮を返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return ファイル圧縮
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public java.lang.Integer getCompression_flg() {
		return compression_flg;
	}

	/**
	 * ファイル圧縮を設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param compression_flg ファイル圧縮
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public void setCompression_flg(java.lang.Integer compression_flg) {
		this.compression_flg = compression_flg;
	}

	/**
	 * ファイルチェックを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return ファイルチェック
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public java.lang.Integer getCheck_flg() {
		return check_flg;
	}

	/**
	 * ファイルチェックを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param check_flg ファイルチェック
	 * 
	 * @see com.clustercontrol.bean.YesNoConstant
	 */
	public void setCheck_flg(java.lang.Integer check_flg) {
		this.check_flg = check_flg;
	}

	/**
	 * 実効ユーザを返す。<BR>
	 * 
	 * @ejb.persistent-field
	 * @ejb.interface-method
	 * 
	 * @return 実効ユーザ
	 */
	public java.lang.String getEffective_user() {
		return effective_user;
	}

	/**
	 * 実効ユーザを設定する。<BR>
	 * 
	 * @ejb.interface-method
	 * 
	 * @param effective_user 実効ユーザ
	 */
	public void setEffective_user(java.lang.String effective_user) {
		this.effective_user = effective_user;
	}

	/**
	 * ジョブ情報を取得する。<BR>
	 * 
	 * @ejb.interface-method view-type="local"
	 * 
	 * @return ジョブ情報
	 * 
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoUtil
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoPK
	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobInfoBean#ejbFindByPrimaryKey(JobInfoPK)
	 */
	public JobInfoLocal getJobInfo() {
		JobInfoLocal jobInfo = null;
		try {
			jobInfo = JobInfoUtil.getLocalHome().findByPrimaryKey(new JobInfoPK(getSession_id(), getJobunit_id(), getJob_id()));
		} catch (FinderException e) {
		} catch (NamingException e) {
		}
		return jobInfo;
	}

	/**
	 * 履歴情報を作成する。<BR>
	 * ジョブファイル転送情報をジョブファイル転送マスタから作成します。<BR>
	 * 
	 * @ejb.home-method view-type="both"
	 * 
	 * @param sessionId セッションID
	 * @param jobunitId 所属ジョブユニットのジョブID
	 * @param jobs ジョブIDのコレクション
	 * @throws javax.ejb.CreateException
	 * 
	 * @see com.clustercontrol.jobmanagement.dao.JobFileInfoDAOImpl#makeSession(String, String, Collection)
	 */
	public Collection ejbHomeMakeSession(String sessionId, String jobunitId, Collection jobs) throws javax.ejb.CreateException{
		JobFileInfoDAOImpl jfiDAO = new JobFileInfoDAOImpl();

		return jfiDAO.makeSession(sessionId, jobunitId, jobs);
	}

}
